@@ -6,7 +6,7 @@
 use v5.22;
 
 package Crypt::EAMessage;
-$Crypt::EAMessage::VERSION = '1.001';
+$Crypt::EAMessage::VERSION = '1.002';
 # ABSTRACT: Simple-to-use Abstraction of Encrypted Authenticated Messages
 
 use strict;
@@ -117,7 +117,7 @@ sub encrypt_auth_ascii($self, $input) {
 }
 
 sub _encrypt_auth_internal($self, $input) {
-    my $random = Bytes::Random::Secure->new(Bits => 1024, NonBlocking => 1);
+    state $random = Bytes::Random::Secure->new(Bits => 1024, NonBlocking => 1);
     my $nonce = $random->bytes(16);
 
     my $frozen = nfreeze(\$input);
@@ -176,7 +176,7 @@ Crypt::EAMessage - Simple-to-use Abstraction of Encrypted Authenticated Messages
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
